"use strict";
// Copyright (c) 2016-2025, Brandon Lehmann <brandonlehmann@gmail.com>
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
Object.defineProperty(exports, "__esModule", { value: true });
exports.PerformanceMonitor = void 0;
const perf_hooks_1 = require("perf_hooks");
class PerformanceMonitor {
    constructor() {
        this._startTime = perf_hooks_1.performance.now();
        this.genesis = this._startTime;
    }
    /**
     * Returns the current mark
     */
    get current_mark() {
        return this._startTime;
    }
    /**
     * Sets the mark
     */
    mark() {
        this._startTime = perf_hooks_1.performance.now();
    }
    /**
     * Returns the amount of time passed in ms since the last mark or the construction of the instance
     *
     * @param decimals
     */
    measure(decimals = 8) {
        return this.format(perf_hooks_1.performance.now() - this._startTime, decimals);
    }
    /**
     * Returns the amount of time passed in ms since the last mark or the construction of the instance
     * and then advanced the mark to now
     *
     * @param decimals
     */
    measureAndMark(decimals = 8) {
        const measure = this.measure(decimals);
        this.mark();
        return measure;
    }
    /**
     * Returns the amount of time passes in ms since the instance was created
     *
     * @param decimals
     */
    total(decimals = 8) {
        return this.format(perf_hooks_1.performance.now() - this.genesis, decimals);
    }
    /**
     * Truncates the number to the specified decimal places
     *
     * @param ms
     * @param decimals
     * @private
     */
    format(ms, decimals = 8) {
        return parseFloat(ms.toFixed(decimals));
    }
}
exports.default = PerformanceMonitor;
exports.PerformanceMonitor = PerformanceMonitor;
//# sourceMappingURL=index.js.map